@@ -23,7 +23,10 @@ pub struct ReportD88 {
     pub path: Option<String>,
     pub noinfo_flg: bool,
     pub nocolor_flg: bool,
+    pub summary_only_flg: bool,
     pub sort_by_sector: bool,
+    pub verbose_flg: bool,
+
     pub position: Option<Position>,
     pub d88fileio: D88FileIO,
 }
@@ -42,6 +45,8 @@ impl ReportD88 {
 
         let _noinfo_flg: bool = _cmdline_info.is_present("no-info");
         let _nocolor_flg: bool = _cmdline_info.is_present("no-color");
+        let _summary_only_flg: bool = _cmdline_info.is_present("summary");
+        let _verbose_flg: bool = _cmdline_info.is_present("verbose");
         let mut _sort_by_sector: bool = _cmdline_info.is_present("Sort by Disk Sector Order");
 
         let _position = if let Some(pos) = _cmdline_info.value_of("TRACK,SIDE,SECTOR") {
@@ -70,7 +75,10 @@ impl ReportD88 {
             noinfo_flg: _noinfo_flg,
             nocolor_flg: _nocolor_flg,
             sort_by_sector: _sort_by_sector,
+            summary_only_flg: _summary_only_flg,
+            verbose_flg: _verbose_flg,
             position: _position,
+
             d88fileio: D88FileIO::default(),
         }
     }
@@ -126,7 +134,17 @@ impl ReportD88 {
             self.print_offset_bar();
             self.report_sector(sector);
         } else {
-            // Report All
+            // Summary
+            if self.summary_only_flg || self.verbose_flg {
+                let _ = self.report_d88_summary();
+            }
+
+            // Byte Image
+            if self.summary_only_flg {
+                return;
+            }
+            println!();
+            println!();
             let _ = self.report_d88_header();
             for track in self.d88fileio.disk.track_tbl.iter() {
                 self.report_track(track);
@@ -144,7 +162,123 @@ impl ReportD88 {
         self.print_sector(sector);
     }
 
-    /// Report D88 Header (Helper function)
+    /// Report D88 Summary (Helper function)
+    ///
+    /// `report_d88` から呼び出される内部関数。  
+    /// D88ファイルのサマリ情報を表示する
+    ///
+    /// # Argument
+    ///
+    ///   * `reader` BufferReader instance at D88 File
+    ///
+    /// # Return
+    ///
+    ///   * if Success, return D88 Header Size.  
+    ///   * if Error, return 0
+    ///
+    #[allow(clippy::format_in_format_args)]
+    pub fn report_d88_summary(&self) -> usize {
+        // Get File Header
+        //
+        let header = &(self.d88fileio.disk.header);
+
+        // ----------------------------------------
+        // Report File Header Summary
+        // ----------------------------------------
+        self.print_d88_file_header_title_bar();
+        println!("  {}", self.d88fileio.disk.get_disk_name());
+        println!("  Protect{}", self.d88fileio.disk.get_disk_write_protect());
+        println!("  {}", self.d88fileio.disk.get_disk_type());
+        println!("  {}", self.d88fileio.disk.get_disk_size());
+        println!();
+        println!();
+
+        // ----------------------------------------
+        // Report Track Offset Table
+        // ----------------------------------------
+        self.print_track_offset_table_bar();
+        for n in 0..164 {
+            // format
+            let track_num_formated = format!("{0:2x}h {0:3}d", n);
+            let track_offset_formated = if header.track_offset_tbl[n] == 0 {
+                "------".to_string()
+            } else {
+                format!("{:06x}", header.track_offset_tbl[n])
+            };
+
+            //
+            if (n % 8) == 0 {
+                println!();
+
+                if self.nocolor_flg {
+                    print!("{}  {} ", track_num_formated, track_offset_formated);
+                } else {
+                    print!(
+                        "{}  {} ",
+                        Color::Cyan.paint(track_num_formated),
+                        track_offset_formated
+                    );
+                }
+            } else {
+                print!("{} ", track_offset_formated);
+            }
+        }
+        println!();
+
+        // ----------------------------------------
+        // Report All Sector Summary
+        // ----------------------------------------
+        println!();
+        println!();
+
+        self.print_sector_summary_bar();
+
+        for track in self.d88fileio.disk.track_tbl.iter() {
+            for (sector_ct, sector) in track.sector_tbl.iter().enumerate() {
+                //
+                let tso_formated = if sector_ct == 0 {
+                    format!(
+                        "{0:02x}h {0:3}d {1:3}  {2:3} {3:3} ",
+                        sector.header.track,
+                        sector.header.side,
+                        sector.header.sector,
+                        track.number_of_sector
+                    )
+                } else {
+                    format!("... .... ...  {:3} ... ", sector.header.sector)
+                };
+
+                if !self.nocolor_flg {
+                    print!("{} ", Color::Cyan.paint(&tso_formated));
+                } else {
+                    print!("{} ", tso_formated);
+                }
+
+                //
+                let offset_formated = format!("{:06x}h ", sector.offset);
+                if !self.nocolor_flg {
+                    print!("{} ", Color::Cyan.paint(offset_formated));
+                } else {
+                    print!("{} ", offset_formated);
+                }
+
+                println!(
+                    "{}, {}, {}, {}, {}, {}",
+                    sector.get_sector_size(),
+                    sector.get_num_of_sector(),
+                    sector.get_status(),
+                    sector.get_density(),
+                    sector.get_mark(),
+                    sector.get_data_size(),
+                );
+            } // for sector in track.sector_tbl.iter() {
+        } // for track in self.d88fileio.disk.track_tbl.iter() {
+
+        // ----------------------------------------
+        mem::size_of::<D88_Header>()
+    }
+
+    /// Report D88 Summary (Helper function)
     ///
     /// `report_d88` から呼び出される内部関数。  
     /// D88ファイルのヘッダ情報を表示する
@@ -164,56 +298,60 @@ impl ReportD88 {
         //
         let header = &(self.d88fileio.disk.header);
 
-        // Output Track Table
-        //
-        self.print_track_offset_bar();
-        for n in 0..164 {
-            if (n % 8) == 0 {
-                println!();
-
-                if self.nocolor_flg {
-                    print!(
-                        "{}  {:05x} ",
-                        (format!("{0:2x}h {0:3}d", n)),
-                        header.track_tbl[n]
-                    );
-                } else {
-                    print!(
-                        "{}  {:05x} ",
-                        Color::Cyan.paint(format!("{0:2x}h {0:3}d", n)),
-                        header.track_tbl[n]
-                    );
-                }
-            } else {
-                print!("{:05x} ", header.track_tbl[n]);
-            }
-        }
-
-        // Report File Header (Byte Image)
-        //
-        println!();
-        println!();
+        // ----------------------------------------
+        // [ByteImage] D88 File Header
+        //   16byte
+        // ----------------------------------------
         let byte_img;
         #[allow(clippy::clone_on_copy)]
         unsafe {
             byte_img =
                 mem::transmute::<D88_Header, [u8; mem::size_of::<D88_Header>()]>((*header).clone());
         }
-
         self.print_offset_bar();
-        self.print_16byte(&byte_img, 0x0000_u64, ansi_term::Color::Green);
 
-        // Report File Header
-        //
+        self.print_16byte(&byte_img, 0x00000_u64, ansi_term::Color::Green); /////////   0 - 16 byte
+        print!("{}", self.d88fileio.disk.get_disk_name());
+        println!();
+
+        self.print_16byte(&byte_img[16..], 0x00010_u64, ansi_term::Color::Green); //   16 - 31 byte
         print!(
-            "{}, {}, {}, {}",
-            self.d88fileio.disk.get_disk_name(),
+            "{}, {}, {}",
             self.d88fileio.disk.get_disk_write_protect(),
             self.d88fileio.disk.get_disk_type(),
-            self.d88fileio.disk.get_disk_size()
+            self.d88fileio.disk.get_disk_size(),
         );
         println!();
 
+        // ----------------------------------------
+        // [ByteImage] Offset to Track
+        //   32bit(4byte) x 164
+        // ----------------------------------------
+        let mut offset = 0x00020_u64;
+        let mut buf32x4 = [0u32; 4];
+        for (ct, track_offset) in header.track_offset_tbl.iter().enumerate() {
+            buf32x4[ct % 4] = *track_offset;
+            if (ct % 4) == 3 {
+                unsafe {
+                    let buf8x16 = mem::transmute::<[u32; 4], [u8; 16]>(buf32x4); // 32bit x 4 --> 8bit x 16
+                    self.print_16byte(&buf8x16, offset, ansi_term::Color::Yellow);
+                }
+
+                print!("TrackOffset ");
+                for ofst in buf32x4.iter() {
+                    let formated = if *ofst == 0 {
+                        "------".to_string()
+                    } else {
+                        format!("{:06x}", ofst)
+                    };
+                    print!("{} ", formated);
+                }
+                println!();
+                offset += 16;
+            }
+        }
+
+        // ----------------------------------------
         mem::size_of::<D88_Header>()
     }
 
